==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fa/mail.php <==
<?php

return array(
    'a_user_canceled' => 'یک کاربر یک درخواست اقساط در وب سایت را لغو کرده است',
    'a_user_requested' => 'یک کاربر یک مورد را در وبسایت درخواست کرده است',
    'accessory_name' => 'نام لوازم جانبی:',
    'additional_notes' => 'یادداشت های اضافی:',
    'admin_has_created' => 'یک مدیر یک حساب کاربری برای شما در وب سایت وب ایجاد کرده است.',
    'asset' => 'دارایی:',
    'asset_name' => 'نام دارایی',
    'asset_requested' => 'دارایی درخواست شد',
    'asset_tag' => 'برچسب دارایی:',
    'assigned_to' => 'اختصاص یافته به',
    'best_regards' => 'با احترام،',
    'canceled' => 'لغو شد:',
    'checkin_date' => 'تاریخ ورود:',
    'checkout_date' => 'چک کردن تاریخ:',
    'click_to_confirm' => 'لطفا برای پیوستن به این لینک کلیک کنید تا حساب خود را تایید کنید:',
    'click_on_the_link_accessory' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که لوازم جانبی را دریافت کرده اید.',
    'click_on_the_link_asset' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که دارایی را دریافت کرده اید.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY فعلی',
    'Days' => 'روزها',
    'days' => 'روزها',
    'expecting_checkin_date' => 'تاریخ انتظار انتظار:',
    'expires' => 'منقضی می شود',
    'Expiring_Assets_Report' => 'گزارش دارایی های معوق',
    'Expiring_Licenses_Report' => 'گزارش مجوزهای منقضی شده',
    'hello' => 'سلام',
    'hi' => 'سلام',
    'i_have_read' => 'من شرایط استفاده را خوانده ام و موافقم و این مورد را دریافت کرده ام.',
    'item' => 'مورد:',
    'Item_Request_Canceled' => 'درخواست مورد لغو شد',
    'Item_Requested' => 'مورد درخواست شده',
    'link_to_update_password' => 'برای به روزرسانی لطفا بر روی لینک زیر کلیک کنید: web password:',
    'login_first_admin' => 'با نصب مجدد Snipe-IT جدید خود به سیستم وارد شوید',
    'login' => 'ورود:',
    'Low_Inventory_Report' => 'گزارش موجودی کم',
    'min_QTY' => 'حداقل QTY',
    'name' => 'نام',
    'new_item_checked' => 'یک آیتم جدید تحت نام شما چک شده است، جزئیات زیر است.',
    'password' => 'کلمه عبور:',
    'password_reset' => 'تنظیم مجدد رمز عبور',

    'read_the_terms' => 'لطفا شرایط استفاده زیر را بخوانید.',
    'read_the_terms_and_click' => 'لطفا شرایط استفاده زیر را مطالعه کنید و روی لینک زیر کلیک کنید تا تأیید کنید که شما شرایط استفاده را می خوانید و موافقت کرده اید و دارایی را دریافت کرده اید.',
    'requested' => 'درخواست شده:',
    'reset_link' => 'رمز عبور خود را بازنشانی کنید',
    'reset_password' => 'برای تغییر رمز عبور اینجا کلیک کنید:',
    'serial' => 'سریال',
    'supplier' => 'تامین کننده',
    'tag' => 'برچسب',
    'test_email' => 'ایمیل تست از Snipe-IT',
    'test_mail_text' => 'این آزمون از سیستم مدیریت دارایی Snipe-IT است. اگر شما این کار را کردید، ایمیل کار می کند :)',
    'the_following_item' => 'مورد زیر مورد بررسی قرار گرفته است:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'برای بازنشانی: رمز عبور وب، این فرم را تکمیل کنید:',
    'type' => 'تایپ کنید',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'کاربر',
    'username' => 'نام کاربری',
    'welcome' => 'خوش آمدید نام',
    'welcome_to' => 'به وب سایت خوش آمدید',
    'your_credentials' => 'مدارک Snipe-IT شما',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fa/mail.php <==
<?php

return [
    'a_user_canceled' => 'یک کاربر یک درخواست اقساط در وب سایت را لغو کرده است',
    'a_user_requested' => 'یک کاربر یک مورد را در وبسایت درخواست کرده است',
    'accessory_name' => 'نام لوازم جانبی:',
    'additional_notes' => 'یادداشت های اضافی:',
    'admin_has_created' => 'یک مدیر یک حساب کاربری برای شما در وب سایت وب ایجاد کرده است.',
    'asset' => 'دارایی:',
    'asset_name' => 'نام دارایی',
    'asset_requested' => 'دارایی درخواست شد',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'اختصاص یافته به',
    'best_regards' => 'با احترام،',
    'canceled' => 'لغو شد:',
    'checkin_date' => 'تاریخ ورود:',
    'checkout_date' => 'چک کردن تاریخ:',
    'click_to_confirm' => 'لطفا برای پیوستن به این لینک کلیک کنید تا حساب خود را تایید کنید:',
    'click_on_the_link_accessory' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که لوازم جانبی را دریافت کرده اید.',
    'click_on_the_link_asset' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که دارایی را دریافت کرده اید.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY فعلی',
    'Days' => 'روزها',
    'days' => 'روزها',
    'expecting_checkin_date' => 'تاریخ انتظار انتظار:',
    'expires' => 'منقضی می شود',
    'Expiring_Assets_Report' => 'گزارش دارایی های معوق',
    'Expiring_Licenses_Report' => 'گزارش مجوزهای منقضی شده',
    'hello' => 'سلام',
    'hi' => 'سلام',
    'i_have_read' => 'من شرایط استفاده را خوانده ام و موافقم و این مورد را دریافت کرده ام.',
    'item' => 'مورد:',
    'Item_Request_Canceled' => 'درخواست مورد لغو شد',
    'Item_Requested' => 'مورد درخواست شده',
    'link_to_update_password' => 'برای به روزرسانی لطفا بر روی لینک زیر کلیک کنید: web password:',
    'login_first_admin' => 'با نصب مجدد Snipe-IT جدید خود به سیستم وارد شوید',
    'login' => 'ورود:',
    'Low_Inventory_Report' => 'گزارش موجودی کم',
    'min_QTY' => 'حداقل QTY',
    'name' => 'نام',
    'new_item_checked' => 'یک آیتم جدید تحت نام شما چک شده است، جزئیات زیر است.',
    'password' => 'کلمه عبور:',
    'password_reset' => 'تنظیم مجدد رمز عبور',

    'read_the_terms' => 'لطفا شرایط استفاده زیر را بخوانید.',
    'read_the_terms_and_click' => 'لطفا شرایط استفاده زیر را مطالعه کنید و روی لینک زیر کلیک کنید تا تأیید کنید که شما شرایط استفاده را می خوانید و موافقت کرده اید و دارایی را دریافت کرده اید.',
    'requested' => 'درخواست شده:',
    'reset_link' => 'رمز عبور خود را بازنشانی کنید',
    'reset_password' => 'برای تغییر رمز عبور اینجا کلیک کنید:',
    'serial' => 'سریال',
    'supplier' => 'تامین کننده',
    'tag' => 'برچسب',
    'test_email' => 'ایمیل تست از Snipe-IT',
    'test_mail_text' => 'این آزمون از سیستم مدیریت دارایی Snipe-IT است. اگر شما این کار را کردید، ایمیل کار می کند :)',
    'the_following_item' => 'مورد زیر مورد بررسی قرار گرفته است:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'برای بازنشانی: رمز عبور وب، این فرم را تکمیل کنید:',
    'type' => 'تایپ کنید',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'کاربر',
    'username' => 'نام کاربری',
    'welcome' => 'خوش آمدید نام',
    'welcome_to' => 'به وب سایت خوش آمدید',
    'your_credentials' => 'مدارک Snipe-IT شما',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
